% Produce the random geometric graphs
% for a set of sizes.
% we generate a few geometries: the square, the circle,
% the annulus

addpath('../matlab');
rand('state',0); % ensure repeatable results
%ns = [1e3 1e4 1e5 1e6]; % original set of sizes, but this was too many
% the small networks weren't useful, the larger ones 
ns = [5e5];

%% generate squares
for ni = 1:length(ns)
  n = ns(ni); % N for the current graph
  xy = rand(n,2);
  % generate a delauney graph in the square (the default)
  [A,xy]=randgeom(n);
  writeSMAT(sprintf('randgeom-square-%i.smat',n),A,struct('format','%i'));
  dlmwrite(sprintf('randgeom-square-%i.xy',n),xy,'delimiter', ' ', 'precision','%12.9f');
end

%% generate circles
polar = @(r,t) [r.*cos(t) r.*sin(t)];
randcirc = @(n,z) polar(sqrt(rand(n,1)), 2*pi*rand(n,1));

for ni = 1:length(ns)
  n = ns(ni); % N for the current graph
  xy = rand(n,2);
  % generate a delauney graph in the circle
  [A,xy]=randgeom(n,randcirc);
  writeSMAT(sprintf('randgeom-circ-%i.smat',n),A,struct('format','%i'));
  dlmwrite(sprintf('randgeom-circ-%i.xy',n),xy,'delimiter', ' ', 'precision','%12.9f');
end

%% generate annulus
polar = @(r,t) [r.*cos(t) r.*sin(t)];
randtaur = @(n,z) polar(sqrt(0.5*rand(n,1)+0.5), 2*pi*rand(n,1));

for ni = 1:length(ns)
  n = ns(ni); % N for the current graph
  % generate a delauney graph in the annulus
  [A,xy]=randgeom(n,randtaur);
  % remove all long edges in the interior
  [i,j]=find(A);
  d = xy(i,:) - xy(j,:);
  d = sqrt(sum(d.*d,2));
  A2 = sparse(i(d<0.2),j(d<0.2),1,size(A,1),size(A,2)); 
  A = A2;
  writeSMAT(sprintf('randgeom-ann-%i.smat',n),A,struct('format','%i'));
  dlmwrite(sprintf('randgeom-ann-%i.xy',n),xy,'delimiter', ' ', 'precision','%12.9f');
  
end

%% generate hyperbolic network

rand('state',0);
ns = [4000];
for ni = 1:length(ns)
  n = ns(ni); % N for the current graph
  % generate a delauney graph in the annulus
  [A,xy]=randhbnet(n,17,0.6);
  % remove the disconnected pieces
  [ci sizes] = scomponents(A);
  [csize cind] = max(sizes);
  p = ci==cind;
  A = A(p,p);
  xy = xy(p,:);
  writeSMAT(sprintf('rand-hyper-%i.smat',n),A,struct('format','%i'));
  dlmwrite(sprintf('rand-hyper-%i.xy',n),xy,'delimiter', ' ', 'precision','%12.9f');
  
end
