function cents = centralities(A)
% CENTRALITIES Compute various centrality measures on a graph A
%
% cents = centralities(A)
% A is a sparse, undirected adjacency matrix
%

%% Compute centralities
n = size(A,1);
cents = [];
cents(end+1).name = 'degree';
cents(end).c = sum(A,1);

cents(end+1).name = 'inversedegree';
cents(end).c = -sum(A,1);


cents(end+1).name = 'betweenness';
cents(end).c = betweenness_centrality(double(A));

cents(end+1).name = 'katz-loose';
cents(end).c = (speye(n) - 1/(max(sum(A))+1))\ones(n,1);

cents(end+1).name = 'katz-tight';
cents(end).c = (speye(n) - 1/(max(svds(A))+1))\ones(n,1);

cents(end+1).name = 'clustering-coeff';
cents(end).c = clustering_coefficients(A);

[l,c,e,eeff] = path_histogram(A);
cents(end+1).name = 'eccentricity';
cents(end).c = 1./e;

cents(end+1).name = 'eccentricity-eff';
cents(end).c = 1./eeff;

[u,s,v] = svds(double(A),1);
u = u*sign(u(1));
v = v*sign(v(1));

cents(end+1).name = 'hits-auth';
cents(end).c = v;

cents(end+1).name = 'hits-hubs';
cents(end).c = u;

% to add
% others from network analysis chapter 3