%% Evaluate a series of centrality measures

%% Setup paths 
addpath('../../matlab');
addpath('../tools');
addpath('~/dev/matlab-bgl/4.0'); % add MatlabBGL for betweenness-centrality

%% Generate the graph
rand('state',5);
n = 1400;
[A,xy] = randhbnet(n,15,0.6); % not quite n, but should be close
[ci sizes] = scomponents(A);
[csize cind] = max(sizes);
p = ci==cind;
A = A(p,p);
xy = xy(p,:);

n = size(A,1);

% plot it
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k.-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
A = sparse(A);

%% compute centralities
cents = centralities(A);

%%
results = [];
for ci=1:length(cents)
    cents(ci)
    
    % We want each cluster to have about 10% of the graph
    maxvol = 0.1;
    H = hypercluster(A,'maxvol',maxvol/2,'expand',nnz(A)*maxvol/25,...
        'centrality',full(cents(ci).c));

    %% Compute the containment
    C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);

    %% Combine clusters
    S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

    %%
    % evaluate
    stats = overlapping_evaluation(A,S,700)
    
    results(end+1).cent = cents(ci);
    results(end).name = cents(ci).name;
    results(end).eval = stats;
    results(end).rho = stats.rho;
end
