
%% Look at cover-combine details with a few designed tests
addpath('../../matlab');

%% Construct a cycle graph
n =20000;
e = ones(n,1);
A = spdiags([e e], [-1,1],n,n);
A(1,n) = 1;
A(n,1) = 1;
i = 1:n;
xy = [cos(2*pi*(i./n))' sin(2*pi*(i./n))'];

%% Compute clusters on it
H = hypercluster(A,'maxvol',0.05);
%% Show overlap
clf; hold on; axis off;
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);

olap = sum(spones(H));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
%% Compute containment
C = containment(A,H,'alpha',1);
%% Show individual clusters
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
hi = 3;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),15,probs,'filled')
colorbar;
%% Combine
S = combine_clusters(A,C,'maxvol',0.01);
%% Plot the cores
clf; hold on;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
%% Show individual clusters
clf; hold on; axis off;
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
ci = 6;
cv = S(ci,:);
olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,cv);
colormap(hot);
colorbar;
%% Show overlap
clf; hold on; axis off;
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);

olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
%% Evaluate the overlap
% Construct an ideal partitioning of the cycle
nclusters = floor(size(S,1)/2);
nverts = size(S,2);
S1 = sparse(2*nclusters, nverts);
c1 = 1;
for i=1:nclusters
    % compute the size of cluster i
    si = floor(nverts/nclusters) + double(i<=mod(nverts,nclusters)); 
    S1(i,c1:(c1+si-1)) = -1;
    c1 = c1+si;
end
c1 = 1 + floor(nnz(S1(1,:))/2);
S1(2*nclusters,1:c1-1) = -1;
for i=1:nclusters-1
    % compute the size of cluster i
    si = floor(nverts/nclusters) + double(i<=mod(nverts,nclusters));
    S1(nclusters+i,c1:(c1+si-1)) = -1;
    c1 = c1+si;
end
% assign the final cluster
S1(2*nclusters,c1:end) = -1;
% assign cores
c1 = 1 + floor(nnz(S1(1,:))/4);
S1(end,1:c1-1) = 1;
cluster_num = 1;
for i=1:2*nclusters-1
    % compute the size of cluster i
    si = floor(nverts/(2*nclusters)) + double(i<=mod(nverts,2*nclusters));
    S1(cluster_num,c1:(c1+si-1)) = 1;
    cluster_num = cluster_num + nclusters;
    if cluster_num>2*nclusters, cluster_num = cluster_num +1 -2*nclusters; end;
    c1 = c1+si;
end

S1(end,c1:end) = 1;

%%
% Construct a regular partition
nclusters = size(S,1);
S2 = sparse(nclusters, nverts);
c1 = 1;
for i=1:nclusters
    % compute the size of cluster i
    si = floor(nverts/nclusters) + double(i<=mod(nverts,nclusters)); 
    S2(i,c1:(c1+si-1)) = 1;
    c1 = c1+si;
end

%%
T = 10000;
[total,swaps,count]=count_swaps(A,S,'ntrials',100,'nsteps',T);
rho = sum((swaps./T).*count/sum(count))

T = 10000;
[total,swaps,count]=count_swaps(A,S1,'ntrials',100,'nsteps',T);
rho1 = sum((swaps./T).*count/sum(count))

T = 10000;
[total,swaps,count]=count_swaps(A,S2,'ntrials',100,'nsteps',T);
rho2 = sum((swaps./T).*count/sum(count))

rho,rho1,rho2

%%
overlapping_evaluation(A,S)
overlapping_evaluation(A,S1)
overlapping_evaluation(A,S2)