%% Plot statistics on partitions of the cycle using our algorithm

%% 
addpath('../../matlab');
addpath('../tools');

%%
ns = [2000,5000,10000,20000,50000,100000];
ntrials = 1000;

%%
results = [];
for ni = 1:length(ns)
    n = ns(ni);
    
    [A,xy] = cycle_graph(n);
    H = hypercluster(A,'maxvol',0.05);
    C = containment(A,H);
    S = combine_clusters(A,C,'maxvol',0.01);
    
    SO = cycle_overlap(n,size(S,1));
    SP = cycle_partition(n,size(S,1));
    SP2 = cycle_partition(n,ceil(size(S,1)/2));
    
    results(end+1).n = n;
    results(end).eval = overlapping_evaluation(A,S,ntrials);
    results(end).evalO = overlapping_evaluation(A,SO,ntrials);
    results(end).evalP = overlapping_evaluation(A,SP,ntrials);
    results(end).evalP2 = overlapping_evaluation(A,SP2,ntrials);
end    
    
%% Display results as a table
for i=1:length(results)
    r = results(i);
    fprintf('%6i  %4.2f %8.2e  %8.2e  %8.2e  %8.2e\n', ...
        r.n, r.eval.vol_ratio, r.eval.rho, ...
        r.evalO.rho, r.evalP.rho, r.evalP2.rho);
end
            
    
%% Display results as a latex table
for i=1:length(results)
    r = results(i);
    fprintf('\\\\ %6i &  %4.2f   &  %18s &  %18s  & %18s &  %18s\n', ...
        r.n, r.eval.vol_ratio, expnum2latex(r.eval.rho), ...
        expnum2latex(r.evalO.rho), expnum2latex(r.evalP.rho), ...
        expnum2latex(r.evalP2.rho));
end
            
    
