%% Prepare a runtime report

% a graph with its vertices and edges
graphs = { {'email-Enron.smat-cc',33696,361622}
           {'soc-Slashdot0811.smat-sym',77360,1015667}
           {'dico.smat-sym-cc',111982,2750576}
           {'lcsh.smat-cc',144791,394186}
           {'web-Google.smat-sym-cc',855802,8582704}
           {'as-skitter.smat-cc',1694616,22188418}
           {'cit-Patents.smat-sym-cc',3764117,33023481} };
    
%%
vol_reduction = [];
clus_reduction = [];
cond_change = [];

for gdata = graphs'
    gdata = gdata{1}; % extract data
    gname = gdata{1};
   
    stats = load_report(gname);
    nedges = gdata{3};
    
    for stat=stats(:)'
        method = stat.method;
        size_measure = stat.volumeRatio;
        myrho = [size_measure,stat.swappingProb];
        mycomm = [size_measure,stat.pagerankCommunication];
        if ~isempty(strfind(method,'small.')) || ...
           ~isempty(strfind(method,'big.')) || ...
           ~isempty(strfind(method,'med.'))
           inputCond = mean(stat.hclusterStats(:,4));
           outputCond = mean(stat.coresStats(:,4));
           
           inputClusters = size(stat.hclusterStats,1);
           outputClusters = size(stat.coresStats,1);
           
           inputVol = sum(stat.hclusterStats(:,2));
           inputVolRatio = inputVol/nedges;
           outputVolRatio = stat.volumeRatio;
           
           vol_reduction(end+1,:) = [inputVolRatio,outputVolRatio];
           clus_reduction(end+1,:) = [inputClusters,outputClusters];
           cond_change(end+1,:) = [inputCond,outputCond];
        end
    end
end

%%
figsetup;
set(0,'DefaultAxesFontSize',30);
set(0,'DefaultLineMarkerSize',30);

%%
figure(1);
clf;
loglog(vol_reduction(:,1),vol_reduction(:,2),'.');
maxvol = max(vol_reduction(:));
axis equal;
line([1,maxvol],[1,maxvol]);
xlim([1,maxvol]);
ylim([1,maxvol]);

xlabel('Input Volume Ratio'); ylabel('Output Volume Ratio');
transfigure;
print(gcf,'combine-volume-reduction.eps','-depsc2');

%%
figure(1);
clf;
plot(cond_change(:,1),cond_change(:,2),'.');
line([0,1],[0,1]);
xlim([0,1]);
ylim([0,1]);
axis equal;
xlabel('Input Mean Conductance'); ylabel('Output Mean Conductance');
transfigure;
print(gcf,'combine-conductance-change.eps','-depsc2');

%%
figure(1);
clf;
loglog(clus_reduction(:,1),clus_reduction(:,2),'.');
maxclus = max(clus_reduction(:));
line([1,maxclus],[1,maxclus]);
axis equal;
xlim([1,maxclus]);
ylim([1,maxclus]);

xlabel('Input Clusters'); ylabel('Output Clusters');
transfigure;
print(gcf,'combine-cluster-change.eps','-depsc2');
