%% Prepare a runtime report

% a graph with its vertices and edges
graphs = { {'email-Enron.smat-cc',33696,361622}
           {'soc-Slashdot0811.smat-sym',77360,1015667}
           {'dico.smat-sym-cc',111982,2750576}
           {'lcsh.smat-cc',144791,394186}
           {'web-Google.smat-sym-cc',855802,8582704}
           {'as-skitter.smat-cc',1694616,22188418}
           {'cit-Patents.smat-sym-cc',3764117,33023481} };
    
%%
pr = [];
rho = [];
rho_big = [];
rho_med = [];
rho_small = [];
graphid= [];

gswapping = {};

gi = 1;
for gdata = graphs'
    gdata = gdata{1}; % extract data
    gname = gdata{1};
    
    part_rho = NaN;
    part_comm = NaN;
    
    small_pr = [];
    big_pr = [];
    med_pr = [];
    
    small_rho = [];
    big_rho = [];
    med_rho = [];
    
    stats = load_report(gname);
    
    
    for stat=stats(:)'
        method = stat.method;
        size_measure = stat.volumeRatio;
        myrho = [size_measure,stat.swappingProb];
        mycomm = [size_measure,stat.pagerankCommunication];
        if ~isempty(strfind(method,'metis.part'))
            part_rho = stat.swappingProb;
            part_comm = stat.pagerankCommunication;
        elseif ~isempty(strfind(method,'small'))
            small_pr(end+1,:) = mycomm;
            small_rho(end+1,:) = myrho;
        elseif ~isempty(strfind(method,'big'))
            big_pr(end+1,:) = mycomm;
            big_rho(end+1,:) = myrho;            
        elseif ~isempty(strfind(method,'med'))
            med_pr(end+1,:) = mycomm;
            med_rho(end+1,:) = myrho;
        end
    end
    
    small_pr(:,2) = small_pr(:,2)/part_comm;
    med_pr(:,2) = med_pr(:,2)/part_comm;
    big_pr(:,2) = big_pr(:,2)/part_comm;    
    
    small_rho(:,2) = small_rho(:,2)/part_rho;
    med_rho(:,2) = med_rho(:,2)/part_rho;
    big_rho(:,2) = big_rho(:,2)/part_rho;
    
    pr = [pr; small_pr; med_pr; big_pr];
    rho = [rho; small_rho; med_rho; big_rho];
    graphid = [graphid; gi*ones(length([small_rho; med_rho; big_rho]),1)];
    rho_small = [rho_small; small_rho];
    rho_med = [rho_med; med_rho];
    rho_big = [rho_big; big_rho];
    
    [ignore gbase gext] = fileparts(gname);
    gswapping{gi} = {gbase, [small_rho; med_rho; big_rho]};
    gi = gi + 1;

end

%%
figsetup;
figure(1);
clf;
hold on;
linesmap = colormap(lines);
legtext = {};
hs = []; % line handles
for i=1:length(gswapping);
    legtext{i} = gswapping{i}{1};
    currho = gswapping{i}{2};
    hs(i) = plot(currho(:,1),currho(:,2),'.','MarkerSize',15,'Color',linesmap(i,:));
    
end
%scatter(rho(:,1),rho(:,2),15,graphid);

xlabel('Volume Ratio');
ylabel('Relative Swapping Probability');
legend(hs(1:4),legtext{1:4},'Location','N');
legend boxoff;
% handle multiple legends
ah2=axes('position',get(gca,'position'), 'visible','off');
% Legend at axes 2
legend(ah2,hs(5:end),legtext{5:end},'Location','NE');
legend(ah2,'boxoff');
ylim([-0.05,2.05]);
xlims = xlim;
th=text(xlims(2),0.95,'Metis Partitioner');
set(th,'HorizontalAlignment','Right','VerticalAlignment','top');
line(xlim,[1,1],'Color',0.55*[1,1,1]);
xlim(xlims);
box off;

%%
transfigure;
set_figure_size([8,3]);
print(gcf,'swapping-probability-indiv.eps','-depsc2');

%%
transfigure;
%set_figure_size([10,8]);
print(gcf,'swapping-probability-indiv-poster.eps','-depsc2');
%export_fig('swapping-probability-indiv-poster.eps','-transparent');
eps_remove_background('swapping-probability-indiv-poster.eps');