function stats=load_report(graph)
% load the *.report files about the graph and display information about the
% results

report_files = dir([graph '*.report']);

if isempty(report_files)
    error('no report files for graph %s exist',graph);
end

i = 1;
for f = report_files'
    r = read_report(f.name);
    [path,name,ext] = fileparts(f.name);
    r.method = name(length(graph)+2:end);
    r.hclusterStats = read_estats([path,name,'.hcluster.estats']);
    r.hclusterTime = read_time([path,'tmp/',name,'.hcluster.time']);
    r.coresStats = read_estats([path,name,'.cores.estats']);
    r.coresTime = read_time([path,'tmp/',name,'.cores.time']);
    stats(i) = r;
    i = i+1;
end

function dt=read_time(f)
if exist(f,'file')
    lines = textread(f, '%s', 'delimiter', '\n','whitespace','');
    if length(lines)<2
        dt = NaN;
        return;
    end
    realtime=char(lines{2});
    timeval = realtime(5:end);
    dt = parse_bash_time(timeval);
else
    dt = NaN;
end

function dt=parse_bash_time(s)
% time could either be 
% 1.222 
% which means 1.222 seconds
% or
% 5h3m1.222s
s = strtrim(s);

if length(s)==0
    dt = NaN;
    return
end

[num,pos] = textscan(s,'%n',1);
s2 = s(pos+1:end);
if length(s2) == 0
    dt = num{1};
else
    dt = 0;
    % this is some d,h,m,s,: format
    while length(s2) > 0
        [delim,pos] = textscan(s2,'%[dhms:DHMS]',1);
        delim = char(delim{1});
        switch delim
            case ':'
            dt = etime(datevec(s),datevec('0:0:0'));
            return
            
            case {'d','D'}
            dt = dt + num{1}*24*60*60;
            case {'h','H'}
            dt = dt + num{1}*60*60;
            case {'m','M'}
            dt = dt + num{1}*60;
            case {'s','S'}
            dt = dt + num{1};
            otherwise
                error('invalid bash string');
        end
        s2 = s2(pos+1:end);
        if length(s2) == 0
            return
        end
        [num,pos] = textscan(s2,'%n',1);
        s2 = s2(pos+1:end);
        if length(s2) == 0
            error('invalid bash string');
        end
    end
end
        
    
    

function stats=read_estats(f)
if exist(f,'file')
    stats = load(f);
else
    stats = [];
end

function report=read_report(f)
    lines = textread(f, '%s', 'delimiter', '\n','whitespace','');
    report = [];
    for l=lines'
        l = char(l);
        str = genvarname(strtrim(l(1:25)));
        val = str2double(l(26:end));
        report.(str) = val;
    end

