function stats=show_report(graph)
% load the *.report files about the graph and display information about the
% resultsbarh(rho);

stats = load_report(graph);
stats = stats';

% sort the methods
methods = {stats.method};
msort = [];
i = 1;
for method=methods
    method = char(method);
    if ~isempty(strfind(method,'metis'))
        if ~isempty(strfind(method,'metis.part'))
            metis_part = stats(i);
        end
        sval = 1;
    elseif ~isempty(strfind(method,'graclus'))
        sval = 2;
    else 
        sval = 10;
    end
    
    msort(i) = sval;
    i = i + 1;
end

[ignore p] = sort(msort);
stats = stats(p);


methods = {stats.method};

figure(1);
clf;
subplot(1,2,1);
rho = [stats.swappingProb];
barh(rho);
set(gca,'YTick',1:length(rho));
set(gca,'YTickLabel',methods);
xlabel('Swapping Probability');
ylim([0,length(rho)+1])
line(metis_part.swappingProb*[1,1],ylim);


subplot(1,2,2);
comm = [stats.pagerankCommunication];
barh(comm);
set(gca,'YTick',1:length(comm));
set(gca,'YTickLabel',methods);
xlabel('PageRank Communication');
ylim([0,length(comm)+1])
line(metis_part.pagerankCommunication*[1,1],ylim);

figure(3);
clf;
subplot(1,2,1);
totalvol = [stats.volumeRatio];
plot(totalvol, rho, '.');
line(xlim,metis_part.swappingProb*[1,1]);
ylabel('Swapping Probability');
xlabel('Volume Ratio');


subplot(1,2,2);
plot(totalvol, comm, '.');
line(xlim,metis_part.pagerankCommunication*[1,1]);
ylabel('PageRank Communication');
xlabel('Volume Ratio');

figure(2);
clf;
nfigs = ceil(sqrt(length(stats)));

for i=1:length(stats);
    subplot(nfigs,nfigs,i);
    if ~isempty(stats(i).hclusterStats)
        semilogx(stats(i).hclusterStats(:,1),stats(i).hclusterStats(:,4),'bo');
        hold on;
    end
    semilogx(stats(i).coresStats(:,1),stats(i).coresStats(:,4),'r.');
    hold off;
    title(stats(i).method);
    xlim([1,5e5]);
    ylim([0,1]);
end


write_report(stats,'swappingProb');

write_report(stats,'pagerankCommunication');

function write_report(stats,metric)

part_stats=[];
overlap_stats=[];

fprintf('%s\n',metric);

for i=1:length(stats)
    if ~isempty(strfind(stats(i).method,'part'))
        if isempty(part_stats)
            part_stats = stats(i);
        else
            part_stats(end+1) = stats(i);
        end
    else
        if isempty(overlap_stats)
            overlap_stats = stats(i);
        else
            overlap_stats(end+1) = stats(i);
        end
    end
end

fprintf('  Partition Results:\n')
[ignore p] = sort([part_stats.(metric)]);
for i=p(:)'
    fprintf('    %25s  %12g  %4.2f\n',part_stats(i).method,part_stats(i).(metric),...
        mean(part_stats(i).coresStats(:,4)));
end
fprintf('\n');

fprintf('  Overlap Results:\n')
[ignore p] = sort([overlap_stats.(metric)]);
for i=p(:)'
    fprintf('    %25s  %12g  %4.2f  %4.2f\n',overlap_stats(i).method,overlap_stats(i).(metric),...
        mean(overlap_stats(i).coresStats(:,4)), overlap_stats(i).volumeRatio);
end
fprintf('\n');
