#!/usr/bin/env python

"""
smat2metis.py
=============

Convert an smat graph file into a metis graph file for partitioning.

History
-------
:2010-02-04: Initial version
"""

__author__ = 'David F. Gleich'

import sys
import os

def usage():
    print """
    Usage: smat2metis.py smatfile [metisfile]
    If metisfile is not listed, then we append .graph or .mat 
    as the file extension instead of .smat
    """
    
def read_smat(smatfile):
    """ Read an SMAT file into an array of lists """
    smatfile.seek(0,0) # reset the file    
    smatheader = smatfile.readline()
    smatheader = smatheader.split()
    m = int(smatheader[0])
    n = int(smatheader[1])
    nz = int(smatheader[2])
    
    data = [ [] for i in xrange(0,m) ]
    for line in smatfile:
        parts = line.split()
        i = int(parts[0])
        j = int(parts[1])
        # oops, don't handle values just yet
        data[i].append(j)

    return data, m, n, nz
    
def write_metis(filename, m, n, nz, data):
    """ Write a metis file. """
    file = open(filename, 'wt')
    # metis counts nz's as the number of edges... arg
    if m == n:
        # count diagonal edges
        diag_nz = 0 
        for i in xrange(0,m):
            for j in data[i]:
                if i==j: 
                    diag_nz += 1
        metis_nz = (nz - diag_nz)/2
        file.write('%i %i\n'%(m, metis_nz))
    else:
        file.write('%i %i %i\n'%(m, n, nz))
    for i in xrange(0,m):
        data[i].sort()
        file.write(' '.join([ str(j+1) for j in data[i] if i != j]))
        file.write('\n')
    file.close()

def main():
    if len(sys.argv) < 2 or len(sys.argv) > 3:
        usage();
        sys.exit(-1)
    smatfilename = sys.argv[1]
    
    # crack open the smat file and get its size
    smatfile = open(smatfilename,'rt')
    smatheader = smatfile.readline()
    smatheader = smatheader.split()
    m = int(smatheader[0])
    n = int(smatheader[1])
    nz = int(smatheader[2])
    print "Converting %s with %i rows, %i colums, and %i non-zeros ..."%(
        smatfilename, m, n, nz)
        
    
    
    if len(sys.argv)>2:
        metisfilename = sys.argv[2]
    else:
        (basename,ext) = os.path.splitext(smatfilename)
        if m==n:
            metisfilename = basename + ".graph"
        else:
            metisfilename = basename + ".mat"
            
    # read the file
    data, m, n, nz = read_smat(smatfile)
    smatfile.close()
    
    count_nz = 0
    for i in xrange(0,m):
        data[i].sort()
        count_nz += len(data[i])
    
    if count_nz != nz:
        print "Adjusting nz count based on data: %i -> %i", nz, count_nz
    
    
    
    print "Saving %s ..."%(metisfilename)
    write_metis(metisfilename, m, n, count_nz, data)
        
    

if __name__ == '__main__':
    main()
