%% Evaluate the tradeoff between total volume and random walk switching
% In this experiment, we'll have metis produce clusterings with more and
% more overlap, and see how well it'll do in terms of the switching ratios
% as a function of the total volume.  
setup_matlab_path

%% Start with a hyperbolic graph
% It seems to exhibit the same type of nasty behavior as most power law
% graphs.  We'll also replicate these experiments with a powerlaw graph
% next.  
%[A,xy] = load_data('rand-hyper-4000');
%A = spones(load_data('email-Enron'));
A = spones(load_data('cond-mat-2005-fix-cc'));
%A = spones(load_data('usroads-cc'));
maxvol = 10000; % look for clusters about 1/10th of the graph size
combine_maxvol = 0.1;

%% 
% Do the parameter sweep
nrep = 4; % repeat each run to get some reliability.
%nruns = [1:5 ]; % use these values of "nruns" in metis
nruns = [1 2 5 10 20 30]; % use these values of "nruns" in metis
results_vol = zeros(length(nruns),nrep);
results_rho = results_vol;
results_comm = results_vol;
figure;
for nruni=1:length(nruns)
    for repi = 1:nrep        
        H = hypercluster_metis(A,'nruns',nruns(nruni),'maxvol',maxvol,'seed',-1); 
        C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
        S = combine_clusters(A,C,'maxvol',combine_maxvol,'coretype','best');
        stats = overlapping_evaluation(A,S);
        results_vol(nruni,repi) = stats.vol_ratio;
        results_rho(nruni,repi) = stats.rho;
        results_comm(nruni,repi) = stats.pagerank_communication;
        subplot(1,2,1);
        plot(results_vol(:),results_rho(:),'.');
        xlabel('Vol Ratio');
        ylabel('Rho');
        subplot(1,2,2);
        plot(results_vol(:),results_comm(:),'.');
        xlabel('Vol Ratio');
        ylabel('Communication');
        drawnow;
    end
end

%%
% do a parameter sweep with pagerank clusters
nruns = [1 2 4 6 10 12 15]; % use these values of "overlap" in prclusters
nrep = 2;
results_vol = zeros(length(nruns),nrep);
results_rho = results_vol;
results_comm = results_vol;
figure;
for nruni=1:length(nruns)
    for repi = 1:nrep        
        Hp = hypercluster(A,'seed',-1,'maxvol',maxvol,...
            'overlap',nruns(nruni),'expand',250,...
             'maxcond',0.55,'minsize',10);
        Hm = hypercluster_metis(A,'nruns',1,'maxvol',maxvol,'seed',-1); 
        H = [Hm;Hp];
        %H = Hp;
        C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
        S = combine_clusters(A,C,'maxvol',combine_maxvol,'coretype','best');
        stats = overlapping_evaluation(A,S);
        results_vol(nruni,repi) = stats.vol_ratio;
        results_rho(nruni,repi) = stats.rho;
        results_comm(nruni,repi) = stats.pagerank_communication;
        subplot(1,2,1);
        plot(results_vol(:),results_rho(:),'.');
        xlabel('Vol Ratio');
        ylabel('Rho');
        subplot(1,2,2);
        plot(results_vol(:),results_comm(:),'.');
        xlabel('Vol Ratio');
        ylabel('Communication');
        drawnow;
    end
end