%% Prepare a figure showing a definitive benefit to overlapping clustering

%% Setup
% Make sure the paths have been setup by |setup_matlab_path| in the root
% directory.  

%% Load data
A = spones(load_data('usroads-cc'));

maxvol=0.01; % look for small partitions

%% Construct a partition with metis
Hm = hypercluster_metis(A,'maxvol',maxvol,'nruns',1);
S = combine_clusters(A,Hm,'maxvol',maxvol);
metis_stats = overlapping_evaluation(A,S);

metis_stats

%% Construct a sequence of overlapping partitions
noverlap = [1 5 15 100];
nrep = 1;
results_vol = zeros(length(noverlap),nrep);
results_rho = results_vol;
results_comm = results_vol;
hcluster_maxvol = 10000;
expand = 1;
figure;
for noverlapi=1:length(noverlap)
    for repi = 1:nrep        
        H = hypercluster(A,'seed',-1,'maxvol',maxvol/10,...
            'overlap',noverlap(noverlapi),'expand',expand);
        C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
        S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');
        
        stats = overlapping_evaluation(A,S);
        
        results_vol(noverlapi,repi) = stats.vol_ratio;
        results_rho(noverlapi,repi) = stats.rho;
        results_comm(noverlapi,repi) = stats.pagerank_communication;
        
        subplot(1,2,1);
        plot(results_vol(:),results_rho(:),'.');
        line(xlim,metis_stats.rho*[1,1]);
        xlabel('Vol Ratio');
        ylabel('Rho');
        
        subplot(1,2,2);
        plot(results_vol(:),results_comm(:),'.');
        line(xlim,metis_stats.pagerank_communication*[1,1]);
        xlabel('Vol Ratio');
        ylabel('Communication');
        drawnow;
        
        
        
    end
end

%% Prepare a summary figure
figsetup;
figure;

clf;
hold on;
plot(results_vol(:),results_rho(:)/metis_stats.rho,'b.-','MarkerSize',20);
plot(results_vol(:),results_comm(:)/metis_stats.pagerank_communication,'r.-','MarkerSize',20);
xlabel('Volume Ratio');
ylabel('Relative Work');
legend('Swapping Probability','PageRank Communication','Location','SouthWest');
legend boxoff;
ylim([-0.05,1.05]);
xlims = xlim;
th=text(xlims(2),0.95,'Metis Partitioner');
set(th,'HorizontalAlignment','Right','VerticalAlignment','top');
line(xlim,[1,1],'Color',0.55*[1,1,1]);
xlim(xlims);

%%
% save the figure
transfigure;
print(gcf,'overlap-benefit-usroads.eps','-depsc2');