%% A big example
addpath('../../matlab');
rand('state',0);
%[A,xy] = randgeom(5000);
polar = @(r,t) [r.*cos(t) r.*sin(t)];
randtaur = @(n,z) polar(sqrt(0.5*rand(n,1)+0.5), 2*pi*rand(n,1));
[A,xy] = randgeom(5000,randtaur);
maxvol = 0.66;
H = hypercluster(A,'maxvol',maxvol/2,'alpha',0.99,'expand',nnz(A)*maxvol/25);

%%
% Evaluate different types of containment
C = containment(A,H,'alpha',0.995,'method','leavetime','maxsteps',150);
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
hi = 11;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),15,probs,'filled')
colorbar;

%%
% Fix a containment
C = containment(A,H,'alpha',0.995,'method','leavetime','maxsteps',150);
    
%% 
% Visualize the containment
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
%plot(lx,ly,'k.','MarkerSize',5);
%set(gca,'XTick',[]); set(gca,'YTick',[]); box off;

axis square;

for hi=1:min(100,size(C,1))
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),15,probs,'filled')
    %plot(xys(:,1), xys(:,2),'r.','MarkerSize',15);
end
colorbar;

%%
% Visualize the best containment
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
%plot(lx,ly,'k.','MarkerSize',5);
%set(gca,'XTick',[]); set(gca,'YTick',[]); box off;

axis square;

[ci,cj,cv] = find(C);
best_contain = accumarray(cj,cv);
scatter(xy(:,1),xy(:,2),5,best_contain,'filled');
colorbar;

%%
% Combine clusters
S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

%% 
% evaluate
stats = overlapping_evaluation(A,S)

%%
% Plot the cores
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
colormap(hot);
%% 
%Show individual clusters
clf; hold on; axis off;
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
ci = 3;
cv = S(ci,:);
olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,cv.*olap);
colormap(hot);
colorbar;

%%
%Show overlap
clf; hold on; axis off;
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);

olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
