%% Show overlapping clusters of a butterfly.

%% Setup paths 
addpath('../../matlab');
addpath('../tools');

%% Generate the graph
n = 6000;
[A,xy] = butterfly_graph(n); % not quite n, but should be close
% plot it
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
%% Partition the graph
% We want each cluster to have about 25% of the graph
maxvol = 0.25;
H = hypercluster(A,'maxvol',maxvol/2,'expand',nnz(A)*maxvol/25);

%% Compute the containment
C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
    
%% 
% Visualize the containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

hi = 40;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),12,probs,'filled')

colorbar;

%%
% Visualize the best containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

[ci,cj,cv] = find(C);
best_contain = accumarray(cj,cv);
scatter(xy(:,1),xy(:,2),5,best_contain,'filled');
colorbar;

%% Combine clusters
S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

%% 
% evaluate
stats = overlapping_evaluation(A,S)

%%
% Plot the cores
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
colormap(hot);
%% 
%Show individual clusters
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
axis square;
ci = 9;
cv = S(ci,:);
scatter(xy(:,1),xy(:,2),4,cv);
colormap(hot);
%h = colorbar; set(h,'YTick',[-1,0,1]); set(h,'YTickLabel',{'In cluster','Out of cluster','In cluster core'});
print(gcf,'butterfly-core.eps','-depsc2');

%%
%Show overlap
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
axis square;
olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
