%% Show overlapping clusters of a butterfly.

%% Setup paths 
addpath('../../matlab');
addpath('../tools');
addpath('~/dev/matlab-bgl');
%% Generate the graph
%A = readSMAT('~/data/graph-db/newman/netscience-cc.smat');
%xy = kamada_kawai_spring_layout(A);
%xy = fruchterman_reingold_force_directed_layout(A,'progressive',xy,'initial_temp',10);
%% Load the graph
A = readSMAT('../../data/overlapping-clusters.smat');
xy = load('../../data/overlapping-clusters.xy');

%%
% plot it
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
%% Partition the graph
% We want each cluster to have about 25% of the graph
H = hypercluster(A,'maxvol',0.5,'expand',nnz(A)*maxvol/25);

%% Compute the containment
C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
    
%% 
% Visualize the containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

hi = 0;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),12,probs,'filled')

colorbar;

%%
% Visualize the best containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

[ci,cj,cv] = find(C);
best_contain = accumarray(cj,cv);
scatter(xy(:,1),xy(:,2),5,best_contain,'filled');
colorbar;

%% Combine clusters
S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

%% 
% evaluate
stats = overlapping_evaluation(A,S)

%%
% Plot the cores
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
colormap(hot);
%% 
%Show individual clusters
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
colormap([0 0 0; graphclr; redclr]);
set(gca,'Clim',[-1,1]);
axis square;
ci = 1;
cv = S(ci,:);
scatter(xy(:,1),xy(:,2),4,cv);
%h = colorbar; set(h,'YTick',[-1,0,1]); set(h,'YTickLabel',{'In cluster','Out of cluster','In cluster core'});


%%
%Show overlap
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
axis square;
olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
