%% Show overlapping clusters of a butterfly.

%% Setup paths 
addpath('../../matlab');
addpath('../tools');

%% Plot options
graphlw = 0.4;
bkgcolor = 0.83*[1,1,1];
graphclr = 0.55*[1,1,1];
redclr = [0.8,0,0];

%% Generate the graph
A = readSMAT('../../data/hole-mesh.smat');
xy = load('../../data/hole-mesh.xy');
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',graphlw);
set(h,'Color',graphclr); colormap(hot);
%% Partition the graph
% We want each cluster to have about 25% of the graph
maxvol = 0.25;
H = hypercluster(A,'maxvol',maxvol/2,'expand',nnz(A)*maxvol/25);

%% Compute the containment
C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
    
%% 
% Visualize the containment of a dispurse cluster
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',graphlw);
set(h,'Color',graphclr); colormap(hot);
axis square;

hi = 18;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),12,probs,'filled')

add_border(xy,bkgcolor);
set(gcf,'InvertHardCopy','off');
print(gcf,'hole-mesh-contain-1.eps','-depsc2');
    
%% 
% Visualize the containment of a tight cluster
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',graphlw);
set(h,'Color',graphclr); colormap(hot);
axis square;

hi = 26;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),6,probs,'filled')    

add_border(xy,bkgcolor);
set(gcf,'InvertHardCopy','off');
print(gcf,'hole-mesh-contain-2.eps','-depsc2');

%%
% Visualize the best containment
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',graphlw);
set(h,'Color',graphclr);
axis square

[ci,cj,cv] = find(C);
best_contain = accumarray(cj,cv,[],@max);
scatter(xy(:,1),xy(:,2),4,best_contain,'Filled');
colormap(hot);
set(gcf,'InvertHardCopy','off');
add_border(xy,bkgcolor);
print(gcf,'hole-mesh-containment.eps','-depsc2');

%% Combine clusters
S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

%% 
% evaluate
stats = overlapping_evaluation(A,S)

%%
% Plot the cores
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
colormap(hot);
%% 
%Show individual clusters
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-');
set(h,'Color',graphclr,'LineWidth',graphlw);
ci = 4;
cv = S(ci,:);
scatter(xy(:,1),xy(:,2),4,cv,'Filled');
colormap([0 0 0; graphclr; redclr]);
axis square;
set(gcf,'InvertHardCopy','off');
add_border(xy,bkgcolor);
print(gcf,'hole-mesh-core-1.eps','-depsc2');

%%
%Show individual clusters
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-');
set(h,'Color',graphclr,'LineWidth',graphlw);
ci = 2;
cv = S(ci,:);
scatter(xy(:,1),xy(:,2),4,cv,'Filled');
colormap([0 0 0; graphclr; redclr]);
axis square;
set(gcf,'InvertHardCopy','off');
add_border(xy,bkgcolor);
print(gcf,'hole-mesh-core-2.eps','-depsc2');

%%
%Show overlap
close all;
clf; hold on; axis off; set(gcf,'Color',bkgcolor);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-');
set(h,'Color',graphclr,'LineWidth',graphlw);
ci = 2;
cv = S(ci,:);
olap = sum(spones(S));
scatter(xy(:,1),xy(:,2),4,olap,'Filled');
colormap([graphclr; 0 0 0; redclr]);
axis square;
set(gcf,'InvertHardCopy','off');
add_border(xy,bkgcolor);
print(gcf,'hole-mesh-overlap.eps','-depsc2');

