%% Show overlapping clusters of a hyperbolic graph.

%% Setup paths 
addpath('../../matlab');
addpath('../tools');

%% Generate the graph
n = 1500;
[A,xy] = randhbnet(n,15,0.56); % not quite n, but should be close
[ci sizes] = scomponents(A);
[csize cind] = max(sizes);
p = ci==cind;
A = A(p,p);
xy = xy(p,:);
% plot it
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-.','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
%% Partition the graph
% We want each cluster to have about 10% of the graph
maxvol = 0.1;
H = hypercluster(A,'maxvol',maxvol/2,'overlap',30,'maxcond',1,'expand',5);

%% Compute the containment
C = containment(A,H,'alpha',0.99,'method','leavetime','maxsteps',150);
    
%% 
% Visualize the containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

hi = 7;
    [i,hverts,probs] = find(C(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),16,probs,'filled')

colorbar;

%%
% Visualize the best containment
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;

[ci,cj,cv] = find(C);
best_contain = accumarray(cj,cv);
scatter(xy(:,1),xy(:,2),5,best_contain,'filled');
colorbar;

%% Combine clusters
S = combine_clusters(A,C,'maxvol',maxvol,'coretype','best');

%% 
% evaluate
stats = overlapping_evaluation(A,S)

%%
% Plot the cores
clf; hold on; axis off;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]); colormap(hot);
axis square;
[cs vs ignore] = find(S==1);
scatter(xy(vs,1),xy(vs,2),4,cs);
colormap(hot);
%% 
%Show individual clusters
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
axis square;
ci = 11;
cv = S(ci,:);
scatter(xy(:,1),xy(:,2),4,cv);
colormap(hot);
%h = colorbar; set(h,'YTick',[-1,0,1]); set(h,'YTickLabel',{'In cluster','Out of cluster','In cluster core'});
print(gcf,'butterfly-core.eps','-depsc2');

%%
%Show overlap
clf; hold on; axis off; set(gcf,'Color',0.8*[1,1,1]);
[lx,ly] = gplot(A,xy); 
plot(lx,ly,'Color',[0.7,0.7,0.7]);
axis square;
olap = sum(spones(H));
scatter(xy(:,1),xy(:,2),4,olap);
colormap(hot);
colorbar;
