%% Visualize a hyperclustering of a geometric graph
% This script works with the precompiled hyperclustering codes and uses
% them to visualize a hyperclustering (overlapping clustering) of a simple
% geometric graph.

addpath('../tools'); % for export fig
addpath('../../matlab'); % for readSMAT
progdir = '../../overlap-clusters/bin';
hclust_output = 'show_hypercluster.hcluster.smat';
hypercluster = @(filename) system(...
    sprintf('%s %s -out %s -maxvol 1000000', ...
    fullfile(progdir,'hypercluster'), filename, hclust_output));
load_hypercluster = @() readSMAT(hclust_output);

%% A simple hyperclustering
filename = '../../data/randgeom-square-1000';
A = readSMAT([filename '.smat']);
xy = load([filename '.xy']);
hypercluster([filename '.smat']);
H = load_hypercluster();
%% 
% Show a few clusters
clf; hold on;
[lx,ly]=gplot(A,xy); plot(lx,ly,'b-','LineWidth',0.5);
plot(lx,ly,'k.','MarkerSize',5);
%set(gca,'XTick',[]); set(gca,'YTick',[]); box off;
set(gcf,'Color','none');
set(gca,'Color','none');
axis off;

for hi=1:10
    hverts = find(H(hi,:));
    xys = xy(hverts,:);
    k = convhull(xys(:,1),xys(:,2)); 
    p=patch(xys(k,1),xys(k,2),[0.5,0.5,0.5]);
    set(p,'FaceAlpha',0.7);
    plot(xys(:,1),xys(:,2),'r.','MarkerSize',16);
end
export_fig('example-hypercluster-partial.png','-m5');

%% A simple hyperclustering on an annulus
filename = '../../data/randgeom-ann-1000';
A = readSMAT([filename '.smat']);
xy = load([filename '.xy']);
hypercluster([filename '.smat']);
H = load_hypercluster();
%% 
% Show a few clusters
clf; hold on;
[lx,ly]=gplot(A,xy); plot(lx,ly,'b-','LineWidth',0.5);
plot(lx,ly,'k.','MarkerSize',5);
%set(gca,'XTick',[]); set(gca,'YTick',[]); box off;
set(gcf,'Color','none');
set(gca,'Color','none');
axis off;
axis square;

for hi=1:15
    hverts = find(H(hi,:));
    xys = xy(hverts,:);
    k = convhull(xys(:,1),xys(:,2)); 
    p=patch(xys(k,1),xys(k,2),[0,0,0]);
    set(p,'FaceAlpha',0.3);
    plot(xys(:,1),xys(:,2),'r.','MarkerSize',16);
end
%%
export_fig('example-hypercluster-partial-ann.png','-m5');

%% Now compute the containment values for each node as well
filename = '../../data/randgeom-square-100000';
A = readSMAT([filename '.smat']);
xy = load([filename '.xy']);
hypercluster([filename '.smat']);
H = load_hypercluster();
system(sprintf('../../overlap-clusters/bin/pagerank-containment %s %s %s',...
    [filename '.smat'], hclust_output, 'show_hypercluster.containment'));
E = readSMAT('show_hypercluster.containment');
%% 
% Visualize the containment
clf; hold on;
[lx,ly]=gplot(A,xy); h=plot(lx,ly,'k-','LineWidth',0.5);
set(h,'Color',0.6*[1 1 1]);
%plot(lx,ly,'k.','MarkerSize',5);
%set(gca,'XTick',[]); set(gca,'YTick',[]); box off;

axis square;

for hi=1:50
    [i,hverts,probs] = find(E(hi,:));
    xys = xy(hverts,:);
    scatter(xys(:,1),xys(:,2),15,probs,'filled')
    %plot(xys(:,1), xys(:,2),'r.','MarkerSize',15);
end
colorbar;

%% Show vertices at different containment levels
[ei,ej,ev] = find(E);
f = ev>0;
clf;
max_contain = accumarray(ej,ev,[],@max);
min_contain = accumarray(ej,ev,[],@min);
%plot(xy(ei(f),1),xy(ej(f),2),'.','MarkerSize',0.5);
scatter(xy(:,1),xy(:,2),6,max_contain,'filled')
scatter(xy(:,1),xy(:,2),4,min_contain,'filled')
colorbar;


%%
axis off;
set(gcf,'Color','none');
set(gca,'Color','none');
