function x = pagerank_in_clusters(A,C,alpha)
% 
% A = graph structure
% C = cluster indicator C(i,j)=1 means that j is in cluster i
% for overlapping clusterings
%   C(i,j) = 1 means that j is in cluster i and that it is a core
%   C(i,j) = -1 means that j is in cluster i but is not a core.
% alpha = pagerank alpha value (alpha=1 is hard, alpha=0 is easy)

n = size(A,1);
maxit = 5000;
tol = 0.1;

A = A';

% initialize cluster results
clusters = [];
nclusters = size(C,1);
cores = zeros(n,1);
for i=1:nclusters
    clusters(i).nodes = find(C(i,:));
    clusters(i).remote = setdiff(1:n,clusters(i).nodes);
    clusters(i).core = find(C(i,:)==1);
    clusters(i).x = zeros(n,1);
    r = zeros(n,1);
    r(clusters(i).core) = 1;
    cores(clusters(i).core) = i;
    clusters(i).r = r;
end

assert(all(cores>0))

% run iterations
for iter=1:maxit
    for i=1:nclusters
        clusters(i) = pagerank_in_cluster(A,clusters(i),alpha);
    end
    % communicate
    % at this step, we must get the residual on the non-local
    % nodes for each cluster
    r = zeros(n,1); % just aggregate into a global residual following Reid
    for i=1:nclusters
        r(clusters(i).remote) = r(clusters(i).remote) + clusters(i).r(clusters(i).remote);
    end
    % check the norm of the global residual
    sumr = sum(r)
    if sumr < tol
        break
    end
    % now assign the residual
    for i=1:nclusters
        clusters(i).r = zeros(n,1);
        clusters(i).r(clusters(i).core) = r(clusters(i).core);
    end
end

% aggregate pagerank
x = zeros(n,1);
for i=1:nclusters
    x(clusters(i).nodes) = x(clusters(i).nodes) + clusters(i).x(clusters(i).nodes);
end

function cluster=pagerank_in_cluster(A,cluster,alpha)
% within a cluster, run PageRank iterations until we get rank to the
% boundary.


maxit = 10000;
localtol = 0.1;

for iter=1:maxit
    for j=cluster.nodes
        % get neighbors
        topush = cluster.r(j);
        neigh = find(A(:,j))';
        deg = length(neigh);
        cluster.r(j) = 0;
        cluster.x(j) = cluster.x(j)+topush;
        for k=neigh
            cluster.r(k) = cluster.r(k) + alpha*topush/deg;
        end
    end
    sumr = sum(cluster.r(cluster.nodes));
    if sumr<localtol
        break
    end
end