#include <iostream>

#include "set_cover.hpp"

void check_heap();
void check_set_cover();
/** 
 * Run the set_cover algorithm and it's dependencies against
 * a range of tests
 */
int main(int argc, char **argv) {
    check_set_cover();
    check_heap();
    return 0;
}

template <typename type>
struct identity_map {
    type& operator[](type& t) { return t; }
};
template <class type>
identity_map<type> make_identity_map() { 
    return identity_map<type>();
}
template <typename type, typename valuetype>
struct constant_function {
    valuetype cval;
    constant_function(valuetype val) : cval(val) {}
    valuetype operator()(const type&) { return cval; }
};
template <typename type, typename valuetype>
constant_function<type,valuetype> make_constant_function(valuetype val) {
    return constant_function<type,valuetype>(val); 
}
    

void check_set_cover() {
    size_t n=5;
    std::vector<double> cost(3);
    std::vector< std::vector< int > > set_of_sets(3);
    set_of_sets[0].push_back(0);
    set_of_sets[0].push_back(1);
    set_of_sets[0].push_back(2);
    set_of_sets[1].push_back(1);
    set_of_sets[1].push_back(2);
    set_of_sets[1].push_back(3);
    set_of_sets[2].push_back(0);
    set_of_sets[2].push_back(4);
    cost[0] = 1.0; cost[1] = 1.0; cost[2] = 2.0;
    
    std::vector<size_t> sets(3,std::numeric_limits<size_t>::max());
    std::vector<size_t>::iterator setsi, sets_end = 
        approx::greedy_set_cover(n, set_of_sets, cost, make_identity_map<int>(),
           make_constant_function<int>(1.0), sets.begin());
    for (setsi = sets.begin(); setsi != sets_end; ++setsi) {
        std::cout << "picked set " << *setsi << " with value " 
                  << cost[*setsi] << std::endl;
    }
    std::cout << "validate set cover: " 
              << approx::validate_set_cover(n, set_of_sets, 
                    make_identity_map<int>(), sets.begin(), sets_end)
              << std::endl;
             
    
    cost[0] = 1.0; cost[1] = 2.0; cost[2] = 15.0;
    
    sets_end = 
        approx::greedy_set_cover(n, set_of_sets, cost, make_identity_map<int>(),
           make_constant_function<int>(1.0), sets.begin());
    for (setsi = sets.begin(); setsi != sets_end; ++setsi) {
        std::cout << "picked set " << *setsi << " with value " 
                  << cost[*setsi] << std::endl;
    }
    std::cout << "validate set cover: " 
              << approx::validate_set_cover(n, set_of_sets, 
                    make_identity_map<int>(), sets.begin(), sets_end)
              << std::endl;
}



void check_heap() {
    approx::detail::simple_updatable_heap<int,double> heap(27);
    heap.insert(0, 1.);
    heap.insert(1, 0.5);
    std::cout << "heap head: " << heap.min() << " " << heap.minvalue() << std::endl;
    heap.pop();
    std::cout << "here" << std::endl;
    heap.insert(2, 2.5);
    std::cout << "heap head: " << heap.min() << " " << heap.minvalue() << std::endl;
    heap.update(2, 0.5);
    std::cout << "heap head: " << heap.min() << " " << heap.minvalue() << std::endl;
    heap.pop();
    std::cout << "heap head: " << heap.min() << " " << heap.minvalue() << std::endl;
    
    
    heap.pop(); 
    std::cout << "heap size: " << 0 << std::endl;
    
    // insert a bunch of numbers (23) to make sure they come out
    // in sorted order
    for (int i=0; i<23; i++) {
        if (i%2==0) {
            heap.insert(i,1.*(i/2));
        } else {
            heap.insert(i,-1.*((i+1)/2));
        }
    }
    heap.update(5,23.);
    heap.update(10,-5.5);
    while (heap.size() > 0) {
        std::cout << "heap head: " << heap.min() << " " << heap.minvalue() << std::endl;
        heap.pop();
    }
}
