function [S,coremap]=combine_clusters(A,C,varargin)
% COMBINE_CLUSTERS Combine clusters together to get an overlapping clustering
%
% This command is not thread safe, it always writes to a file 
% in the directory with the command
%
% S = combine_clusters(A,C); combine clusters scored with containment
% scores.
% [S,coremap] also returns the coremap, otherwise
% S = combine_clusters(A,'key',value, ...)
% specify optional arguments:
%   'coretype' = 'best'
%   'maxvol' = '_' (use the default maxvol => max(1% of edges,100))
%   'betascale' = 2
%   'volumepenalty' = 5
%   'borderpenalty' = 1

% David F. Gleich
% Copyright, 2010


mydir = fileparts(mfilename('fullpath'));
% parse options
options = struct(varargin{:});
mycmd = fullfile(mydir,'..','overlap-clusters','bin','cover-combine');
mygraphfile = fullfile(mydir,'cover-graph.smat');
myclusterfile = fullfile(mydir,'cover.contain');
myoutfile = fullfile(mydir,'cover-sets.smat');

writeSMAT(mygraphfile,A,struct('format','%i'));
writeSMAT(myclusterfile,C);


coretype = 'best';
maxvol = '_';
betascale = 2;
volumepenalty = 5;
borderpenalty = 1;

if isfield(options,'coretype'), coretype = options.coretype; end
if isfield(options,'maxvol'), maxvol = options.maxvol; end
if isfield(options,'betascale'), betascale = options.betascale; end
if isfield(options,'volumepenalty'), volumepenalty = options.volumepenalty; end
if isfield(options,'borderpenalty'), borderpenalty = options.borderpenalty; end

if ~ischar(maxvol), maxvol = num2str(maxvol); end
mycmd = [mycmd ' ' mygraphfile ' ' myclusterfile ' ' maxvol ' ' myoutfile];
mycmd = [mycmd ' ' ...
    sprintf('%s %f %f %f',coretype, ...
        betascale,volumepenalty,borderpenalty)];

status = system(mycmd);
if status==0
    S = readSMAT(myoutfile);
end
if nargout>1
    % build the map to cores, which occurs for all values that are 1
    [ci vi] = find(S==1);
    coremap = zeros(size(A,1),1);
    coremap(vi) = ci;
    S = spones(S);
end
