function C=containment(A,H,varargin)
% CONTAINMENT Compute containment scores for a hyperclustering
% This command is not thread safe, it always writes to a file 
% in the directory with the command
% C = containment(A,H); run a containment scoring on a graph A given by its
% adjacency matrix for a hyperclustering H
% H = containment(A,'key',value, ...)
% specify optional arguments:
%   'method' = [{'leavetime'},'stayprob']
%   'alpha' = [float | {0.85}] the value of alpha in the PageRank
%       containment
%   'maxsteps' = [int | {25}] the maximum number of random walk steps

% David F. Gleich
% Copyright, 2010


mydir = fileparts(mfilename('fullpath'));
% parse options
options = struct(varargin{:});
mycmd = fullfile(mydir,'..','overlap-clusters','bin','pagerank-containment');
mygraphfile = fullfile(mydir,'containment-graph.smat');
myclusterfile = fullfile(mydir,'containment.hcluster');
myoutfile = fullfile(mydir,'containment.contain');

writeSMAT(mygraphfile,A,struct('format','%i'));
writeSMAT(myclusterfile,H);

mycmd = [mycmd ' ' mygraphfile ' ' myclusterfile ' ' myoutfile];
alpha = 0.99;
method = 'leavetime';
maxsteps = 150;
if isfield(options,'method'), method = options.method; end
if isfield(options,'alpha'), alpha = options.alpha; end
if isfield(options,'maxsteps'), maxsteps = options.maxsteps; end
mycmd = [mycmd ' ' sprintf('%s %f %i',method,alpha,maxsteps)];

status = system(mycmd);
if status==0
    C = readSMAT(myoutfile);
end