function [total,swaps,count]=count_swaps(A,S,varargin)
% COUNT_SWAPS Count cluster swaps in a random walk on overlapping clusters
%
% This command is not thread safe, it always writes to a file 
% in the directory with the command
%
% [total,swaps,count] = count_swaps(A,S,...) counts the number of swaps on
% random particle walks in A on overlapping clustering S.  Total is the
% total number of swaps in all random walks, and count(i) is the number of walks
% with swaps(i) swaps.  
%
% ... = combine_clusters(A,S'key',value, ...)
% specify optional arguments:
%   'nsteps' = [int | {100}] : number of steps in the walk
%   'ntrials' = [int | {100}] : number of walks to use
%   'seed' = [int | {0}] : seed to use for the random generator, 
%      any seed less than 0 means to seed from the current time.

% David F. Gleich
% Copyright, 2010

% History
% -------
% :2010-02-03: Initial version

mydir = fileparts(mfilename('fullpath'));
% parse options
options = struct(varargin{:});
mycmd = fullfile(mydir,'..','overlap-clusters','bin','average-swaps');
mygraphfile = fullfile(mydir,'average-swaps.smat');
myclusterfile = fullfile(mydir,'average-swaps.cores');
myoutfile = fullfile(mydir,'average-swaps.hist');

writeSMAT(mygraphfile,A,struct('format','%i'));
writeSMAT(myclusterfile,S,struct('format','%i'));

seed = 0;
nsteps = 100;
ntrials = 100;

if isfield(options,'seed'), seed = options.seed; end
if isfield(options,'nsteps'), nsteps = options.nsteps; end
if isfield(options,'ntrials'), ntrials = options.ntrials; end

mycmd = [mycmd ' ' mygraphfile ' ' myclusterfile ' ' myoutfile];
mycmd = [mycmd ' ' ...
    sprintf('%i %i %i',ntrials,nsteps,seed)];

status = system(mycmd);
if status==0
    hist = load(myoutfile);
    total = sum(hist(:,1).*hist(:,2));
    swaps = hist(:,1);
    count = hist(:,2);
end