function stats = evaluate_clustering(A,H)
% EVALUATE_CLUSTERING Report statistics on a clustering
%
% stats = evaluate_clustering(A,H) reports statistiscs on a hyperclustering
%   H on graph A.  
%
% For each cluster in H, we compute
%   stats(i,1) = the size of the cluster
%   stats(i,2) = the volume of the cluster
%   stats(i,3) = the cutsize for the cluster
%   stats(i,4) = the conductance of the cluster
%   stats(i,5) = the number of intersecting clusters
%   stats(i,6) = the number of overlapped vertices 
%

% David F. Gleich
% Copyright, 2010

% History
% -------
% :2010-10-25: Added stats output


mydir = fileparts(mfilename('fullpath'));
% parse options
mycmd = fullfile(mydir,'..','overlap-clusters','evaluate_clustering.py');
mygraphfile = fullfile(mydir,'evaluate-clustering-graph.smat');
myclusterfile = fullfile(mydir,'evaluate-clustering.hcluster');
mystatfile = fullfile(mydir,'evaluate-clustering.stats');

writeSMAT(mygraphfile,A);
writeSMAT(myclusterfile,H);

mycmd = [mycmd ' ' mygraphfile ' ' myclusterfile ' ' mystatfile];
mycmd
status = system(mycmd);
if status==0
    stats = load(mystatfile);
end
