function H=hypercluster_metis(A,varargin)
% Run metis to produce a hyperclustering

% David F. Gleich
% Copyright, 2010

% parse options
options = struct(varargin{:});

maxvol = 0.1;
if isfield(options,'maxvol') 
    maxvol = options.maxvol;
end

minvol = 100;
if isfield(options,'minvol') 
    minvol = options.minvol;
end

seed = 0;
if isfield(options,'seed') 
    seed = options.seed;
end

nruns = 10;
if isfield(options,'nruns') 
    nruns = options.nruns;
end

if maxvol < 1
    maxvol = nnz(A)*maxvol;
end
if minvol < 1
    minvol = nnz(A)*minvol;
end

maxparts = floor(nnz(A)/minvol);
minparts = ceil(nnz(A)/maxvol);

% TODO handle this case better
% what happens if minvol > nnz(A)?
maxparts = min(maxparts,minparts*3);
if maxparts<minparts, maxparts=minparts; end

if seed == -1
    rs = RandStream('mt19937ar','seed',sum(100*clock));
else
    rs = RandStream('mt19937ar','seed',seed);
end

H = sparse(size(A,1),0);
for r=1:nruns
    np = randi(rs,[minparts,maxparts],1);
    mseed = randi(rs,[0,65536],1);
    if r==1
        np = minparts;
    elseif r==2
        np = maxparts;
    end
    p = metismex('PartGraphRecursive',A,np,0,[1 1 1],mseed);
    
    uniqclusters = unique(p);
    numclusters = length(uniqclusters);
    for c=1:numclusters
        ci = uniqclusters(c);
        H(:,end+1) = sparse((p == ci)');
    end
end
H = H';
    