function varargout = load_data(graphname)

% Based on GAIMC function...
% LOAD_GAIMC_GRAPH Loads a graph from the gaimc library
%
% load_gaimc_graph is a helper function to load a graph provided with the
% library regardless of the current working directory.  
%
% If it's called without any output arguments, it functions just like a
% load command executed on the .mat file with the graph.  If it's called
% with an output arguemnt, it functions just like a load command with
% output arguments.  It's somewhat complicated to explain because this is
% just a convinence function to make the examples work for any path, and
% not just from the gaimc root directory.
%
% Example:
%   % equivalent to load('graphs/airports.mat') run from the gaimc directory
%   load_gaimc_graph('airports') 
%   % equivalent to P=load('graphs/kt-7-2.mat') run from the gaimc directory
%   P=load_gaimc_graph('kt-7-2.mat') 
%   % so you don't have to put the path in for examples!

% David F. Gleich
% Copyright, Stanford University, 2008-2009

% History
% 2010-09-29: Initial coding


path=fileparts(mfilename('fullpath'));
data = 'data';
data_dir = fullfile(path,'..',data);
%% find the graph
if exist(fullfile(path,'..',data,[graphname '.smat-sym-cc']))
    varargout{1} = readSMAT(fullfile(path,'..',data,[graphname '.smat-sym-cc']));
elseif exist(fullfile(path,'..',data,[graphname '.smat-cc']))
    varargout{1} = readSMAT(fullfile(path,'..',data,[graphname '.smat-cc']));
elseif exist(fullfile(path,'..',data,[graphname '.smat-sym']))
    varargout{1} = readSMAT(fullfile(path,'..',data,[graphname '.smat-sym']));
else
    varargout{1} = readSMAT(fullfile(path,'..',data,[graphname '.smat']));
end
if nargout>1
    exts = {'.xy','.xyz','.3d','.2d'};
    for ext = exts
        coordfile = fullfile(path,'..',data,[graphname char(ext)]);
        if exist(coordfile,'file')
            varargout{2} = load(coordfile);
            return
        end
    end
    warning('overlapping:load_data','coordinates requested, but none available');
    varargout{2} = []; % no coordinates
end