function [G,xy] = randhbnet(n,R,alpha)
% RANDHBNET Generate a random geometric network in hyperbolic space
%
% [G,xy] = randhbnet(n,R,K) 
%
% See Krioukov et al. 10.1103/PhysRevE.80.035101 for more details.

% David F. Gleich
% Copyright, 2010

% History
% :2010-07-27: Initial implementation

theta = 2*pi*rand(n,1)-pi;
rho = (log(rand(n,1)/alpha))/alpha+R;  % check this against the paper, they do something with sinh/cosh

xy = [rho.*cos(theta) rho.*sin(theta)];

% hyperbolic distance function
d = @(r1,t1,r2,t2) acosh(cosh(r1)*cosh(r2) - sinh(r1)*sinh(r2)*cos(abs(t1-t2)));

n = min(numel(rho),numel(theta));
G = zeros(n);
for i=1:n
    for j=i+1:n
        if d(rho(i),theta(i),rho(j),theta(j)) <= R
            G(i,j) = 1;
        end
    end
end
G = G|G';

